# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/laraclass/classified/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/laraclass/classified/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Laraclass\\Classified\\": "packages/laraclass/classified/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Laraclass\Classified\Providers\ClassifiedServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Classified'  => Laraclass\Classified\Facades\Classified::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Laraclass\\ClassifiedTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Laraclass\Classified\Providers\ClassifiedServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Laraclass\Classified\Providers\ClassifiedServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Laraclass\Classified\Providers\ClassifiedServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/classified/{modulename}

**User**

    http://path-to-route-folder/user/classified/{modulename}

**Public**

    http://path-to-route-folder/classifieds


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/classified/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/classified/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/classified/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/classified/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/classified/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/classified/{modulename}/{slug}
    METHOD: GET